#! /usr/lib/veetest/veetest -r
(revision "A.00.01")
(date "Sun 05/Jan/1992")
(component 0 "Context"
 (name "String Functions Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "Note"
   (name "To Operate:")
   (interface
   )
   (implementation
    (component text 3 5
     Enter some String data
     and other parameters,
     then press RUN.
    )
   )
   (views
    (icon
     (extent 110 0)
     (iconImage "notepad.icon")
    )
    (detail
     (origin 350 111)
     (extent 221 79)
     (editing enabled)
    )
    (active detail)
   )
  )
  (component 1 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 592 108)
     (extent 396 84)
     (editing enabled)
    )
    (active detail)
   )
  )
  (component 2 "TextDisplay"
   (name "Extracted String")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 154 0)
    )
    (detail
     (origin 596 411)
     (extent 228 38)
    )
    (active detail)
   )
  )
  (component 3 "Formula"
   (name "strFromThru(str,from,thru)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "str")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "from")
     (lock name constraints)
    )
    (input 3
     (type data)
     (name "thru")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "substr")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "strFromThru(str,from,thru)")
   )
   (views
    (icon
     (origin 318 413)
     (extent 244 34)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "TextDisplay"
   (name "Index of char")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 127 0)
    )
    (detail
     (origin 601 502)
     (extent 219 37)
    )
    (active detail)
   )
  )
  (component 5 "Formula"
   (name "strPosChar(str,char)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "str")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "char")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "index")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "strPosChar(str,char)")
   )
   (views
    (icon
     (origin 345 508)
     (extent 190 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 6 "TextDisplay"
   (name "Number of Chars")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 145 0)
    )
    (detail
     (origin 601 242)
     (extent 219 37)
    )
    (active detail)
   )
  )
  (component 7 "Formula"
   (name "strLen(str)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "str")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "strLen(str)")
   )
   (views
    (icon
     (origin 385 248)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 8 "TextDisplay"
   (name "Extracted String")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 154 0)
    )
    (detail
     (origin 596 321)
     (extent 228 38)
    )
    (active detail)
   )
  )
  (component 9 "Formula"
   (name "strFromLen(str,from,len)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "str")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "from")
     (lock name constraints)
    )
    (input 3
     (type data)
     (name "len")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "substr")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "strFromLen(str,from,len)")
   )
   (views
    (icon
     (origin 327 323)
     (extent 226 34)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 10 "LiteralConstant"
   (name "SubStr")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "SubStr")
     (datum "frag")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
     (extent 78 0)
    )
    (detail
     (origin 10 606)
     (extent 201 28)
    )
    (active detail)
   )
  )
  (component 11 "Formula"
   (name "strPosstr(str1,str2)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "str1")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "str2")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "index")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "strPosStr(str1,str2)")
   )
   (views
    (icon
     (origin 345 598)
     (extent 190 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 12 "TextDisplay"
   (name "Index of char")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 127 0)
    )
    (detail
     (origin 601 592)
     (extent 219 37)
    )
    (active detail)
   )
  )
  (component 13 "LiteralConstant"
   (name "Char(s)")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Char(s)")
     (datum "e")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
     (extent 78 0)
    )
    (detail
     (origin 10 516)
     (extent 201 28)
    )
    (active detail)
   )
  )
  (component 14 "Constant"
   (name "Num Char")
   (subType "Integer")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Int32")
     (lock name constraints)
    )
   )
   (implementation
    (component value Int32
     (name "Num Char")
     (datum 6)
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Int32
     (datum 0)
    )
   )
   (views
    (icon
     (extent 110 0)
    )
    (detail
     (origin 11 424)
     (extent 198 33)
     (showFormat int)
    )
    (active detail)
   )
  )
  (component 15 "Constant"
   (name "Start Pos.")
   (subType "Integer")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Int32")
     (lock name constraints)
    )
   )
   (implementation
    (component value Int32
     (name "Start Pos.")
     (datum 2)
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Int32
     (datum 0)
    )
   )
   (views
    (icon
     (extent 110 0)
    )
    (detail
     (origin 11 325)
     (extent 199 30)
     (showFormat int)
    )
    (active detail)
   )
  )
  (component 16 "Formula"
   (name "strRev(str)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "str")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "strRev(str)")
   )
   (views
    (icon
     (origin 375 678)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 17 "TextDisplay"
   (name "Reversed String")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 145 0)
    )
    (detail
     (origin 596 671)
     (extent 228 38)
    )
    (active detail)
   )
  )
  (component 18 "Context"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (trigMode deg)
    (locked no)
    (component 0 "IfThenElse"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 365 350)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "Toggle"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (origin 201 343)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "Context"
     (name "Info About This Example")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (trigMode deg)
      (locked no)
      (component 0 "Note"
       (name "NotePad")
       (description 2 8
        This notepad is displayed as a Show on Execute
        panel to present the information to the reader.
       )
       (interface
       )
       (implementation
        (component text 8 9
         PURPOSE:     Demonstrate use of the Math --> String functions.
         
         USER INPUT REQUIRED:  Adjust "String" and other parameters, if desired, then press RUN.
         
         EXPLANATION: Each of the Math String functions are presented with an input string and
                   other optional parameters as needed.  The resulting strings or character
                   indexes are displayed.
         
        )
       )
       (views
        (icon
         (origin 160 185)
         (extent 78 25)
        )
        (detail
         (origin 36 162)
         (extent 848 437)
         (editing enabled)
        )
        (active icon)
       )
      )
      (component 1 "Confirm"
       (name "DONE")
       (description 7 8
        This tiny "thread" begins running when the 
        enclosing UserObject is executed.  When the user
        acknowledges the OK/DONE button, there is nothing
        left to execute, so the thread ends.  Since there
        are not other threads running, the User Object
        is completed and will exit, removing the Show on
        Execute pop-up display.
       )
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 171 252)
         (extent 58 37)
        )
        (detail
         (origin 156 253)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (extent 849 571)
       (panel
        (origin 38 164)
        (extent 845 533)
        (widget 1 icon
         (title off)
         (origin 437 649)
         (extent 58 37)
        )
        (widget 0 detail
         (title off)
         (origin 49 174)
         (extent 827 463)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 352 418)
       (extent 217 25)
      )
      (detail
       (origin 17 140)
       (extent 866 520)
       (configuration
       )
      )
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D2:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 175 368)
     (extent 110 25)
    )
    (panel
     (origin 11 112)
     (extent 319 77)
     (widget 1 icon
      (title off)
      (origin 113 125)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D1:1 D0:1
       (Point 317 362)
       (Point 362 362)
      )
      (connect D2:0 D1:1
       (Point 460 445)
       (Point 460 460)
       (Point 180 460)
       (Point 180 362)
       (Point 198 362)
      )
      (connect D0:1 D2:0
       (Point 413 352)
       (Point 460 352)
       (Point 460 415)
      )
     )
    )
    (active panel)
    (active panel)
   )
  )
  (component 19 "Formula"
   (name "strUp(str)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "str")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "strUp(str)")
   )
   (views
    (icon
     (origin 375 758)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 20 "TextDisplay"
   (name "Extracted String")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 154 0)
    )
    (detail
     (origin 596 841)
     (extent 228 38)
    )
    (active detail)
   )
  )
  (component 21 "Formula"
   (name "strDown(str)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "str")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "strDown(str)")
   )
   (views
    (icon
     (origin 391 848)
     (extent 118 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 22 "TextDisplay"
   (name "Extracted String")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 154 0)
    )
    (detail
     (origin 595 752)
     (extent 311 37)
    )
    (active detail)
   )
  )
  (component 23 "Formula"
   (name "Quote the String")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "\"\\\"\"+a+\"\\\"\"")
   )
   (views
    (icon
     (origin 197 598)
     (extent 154 64)
     (iconImage "formula.icon")
    )
    (detail
     (origin 315 933)
     (extent 231 35)
    )
    (active detail)
   )
  )
  (component 24 "Formula"
   (name "Quote the String")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "\"\\\"\"+a+\"\\\"\"")
   )
   (views
    (icon
     (origin 197 598)
     (extent 154 64)
     (iconImage "formula.icon")
    )
    (detail
     (origin 315 1022)
     (extent 230 36)
    )
    (active detail)
   )
  )
  (component 25 "Formula"
   (name "strTrim(str)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "str")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "strTrim(str)")
   )
   (views
    (icon
     (origin 91 1028)
     (extent 118 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 26 "LiteralConstant"
   (name "String with whitespace")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "String with whitespace")
     (datum "     supercalifragalistic   ")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
     (extent 208 0)
    )
    (detail
     (origin 9 846)
     (extent 282 28)
    )
    (active detail)
   )
  )
  (component 27 "TextDisplay"
   (name "Untrimed String")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 145 0)
    )
    (detail
     (origin 598 932)
     (extent 284 36)
    )
    (active detail)
   )
  )
  (component 28 "TextDisplay"
   (name "Trimed String")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 127 0)
    )
    (detail
     (origin 593 1021)
     (extent 294 38)
    )
    (active detail)
   )
  )
  (component 29 "LiteralConstant"
   (name "String")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "String")
     (datum "supercalifragalistic")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
     (extent 78 0)
    )
    (detail
     (origin 10 236)
     (extent 201 28)
    )
    (active detail)
   )
  )
  (configuration
   (connect D3:1 D2:1)
   (connect D29:1 D3:1)
   (connect D15:1 D3:2)
   (connect D14:1 D3:3)
   (connect D5:1 D4:1)
   (connect D29:1 D5:1)
   (connect D13:1 D5:2)
   (connect D7:1 D6:1)
   (connect D29:1 D7:1)
   (connect D9:1 D8:1)
   (connect D29:1 D9:1)
   (connect D15:1 D9:2)
   (connect D14:1 D9:3)
   (connect D29:1 D11:1)
   (connect D10:1 D11:2)
   (connect D11:1 D12:1)
   (connect D29:1 D16:1)
   (connect D16:1 D17:1)
   (connect D29:1 D19:1)
   (connect D21:1 D20:1)
   (connect D29:1 D21:1)
   (connect D19:1 D22:1)
   (connect D26:1 D23:1)
   (connect D25:1 D24:1)
   (connect D26:1 D25:1)
   (connect D23:1 D27:1)
   (connect D24:1 D28:1)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 1004 664)
   (configuration
    (connect D3:1 D2:1
     (Point 564 430)
     (Point 593 430)
    )
    (connect D29:1 D3:1
     (Point 213 250)
     (Point 230 250)
     (Point 230 330)
     (Point 310 330)
     (Point 310 420)
     (Point 315 420)
    )
    (connect D15:1 D3:2
     (Point 212 340)
     (Point 290 340)
     (Point 290 430)
     (Point 315 430)
    )
    (connect D14:1 D3:3
     (Point 211 440)
     (Point 315 440)
    )
    (connect D5:1 D4:1
     (Point 537 520)
     (Point 598 520)
    )
    (connect D29:1 D5:1
     (Point 213 250)
     (Point 230 250)
     (Point 230 330)
     (Point 310 330)
     (Point 310 390)
     (Point 330 390)
     (Point 330 510)
     (Point 342 510)
    )
    (connect D13:1 D5:2
     (Point 213 530)
     (Point 342 530)
    )
    (connect D7:1 D6:1
     (Point 497 260)
     (Point 598 260)
    )
    (connect D29:1 D7:1
     (Point 213 250)
     (Point 230 250)
     (Point 230 260)
     (Point 382 260)
    )
    (connect D9:1 D8:1
     (Point 555 340)
     (Point 593 340)
    )
    (connect D29:1 D9:1
     (Point 213 250)
     (Point 230 250)
     (Point 230 330)
     (Point 324 330)
    )
    (connect D15:1 D9:2
     (Point 212 340)
     (Point 324 340)
    )
    (connect D14:1 D9:3
     (Point 211 440)
     (Point 300 440)
     (Point 300 350)
     (Point 324 350)
    )
    (connect D29:1 D11:1
     (Point 213 250)
     (Point 230 250)
     (Point 230 330)
     (Point 310 330)
     (Point 310 390)
     (Point 330 390)
     (Point 330 600)
     (Point 342 600)
    )
    (connect D10:1 D11:2
     (Point 213 620)
     (Point 342 620)
    )
    (connect D11:1 D12:1
     (Point 537 610)
     (Point 598 610)
    )
    (connect D29:1 D16:1
     (Point 213 250)
     (Point 230 250)
     (Point 230 330)
     (Point 310 330)
     (Point 310 390)
     (Point 330 390)
     (Point 330 610)
     (Point 350 610)
     (Point 350 690)
     (Point 372 690)
    )
    (connect D16:1 D17:1
     (Point 487 690)
     (Point 593 690)
    )
    (connect D29:1 D19:1
     (Point 213 250)
     (Point 230 250)
     (Point 230 330)
     (Point 310 330)
     (Point 310 390)
     (Point 330 390)
     (Point 330 610)
     (Point 350 610)
     (Point 350 770)
     (Point 372 770)
    )
    (connect D21:1 D20:1
     (Point 511 860)
     (Point 593 860)
    )
    (connect D29:1 D21:1
     (Point 213 250)
     (Point 230 250)
     (Point 230 330)
     (Point 310 330)
     (Point 310 390)
     (Point 330 390)
     (Point 330 610)
     (Point 350 610)
     (Point 350 770)
     (Point 360 770)
     (Point 360 800)
     (Point 370 800)
     (Point 370 860)
     (Point 388 860)
    )
    (connect D19:1 D22:1
     (Point 487 770)
     (Point 592 770)
    )
    (connect D26:1 D23:1
     (Point 293 860)
     (Point 300 860)
     (Point 300 900)
     (Point 290 900)
     (Point 290 950)
     (Point 312 950)
    )
    (connect D25:1 D24:1
     (Point 211 1040)
     (Point 312 1040)
    )
    (connect D26:1 D25:1
     (Point 293 860)
     (Point 300 860)
     (Point 300 900)
     (Point 70 900)
     (Point 70 1040)
     (Point 88 1040)
    )
    (connect D23:1 D27:1
     (Point 548 950)
     (Point 595 950)
    )
    (connect D24:1 D28:1
     (Point 547 1040)
     (Point 590 1040)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
